@@ -7,8 +7,8 @@ class BidHistorySchema(CamelCaseSchema):
 
   id = fields.UUID()
   bid_id = fields.UUID()
-  source_type = fields.String()
-  source_id = fields.Integer()
+  source_type = fields.String(allow_none=True)
+  source_id = fields.Integer(allow_none=True)
   amount = fields.Integer()
   carrier_id = fields.UUID(allow_none=True)
   pickup_date = fields.Date()
