@@ -45,6 +45,12 @@ class LocalConfig(Config):
 class DevelopmentConfig(Config):
   """Configurations for running in dev mode, with a remote database."""
   
+class StagingConfig(Config):
+  """Configurations for running in dev mode, with a remote database."""
+  BOOK_LOAD_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:booking-agent-book-load-staging'
+  BOOKING_ASSISTANT_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:booking-assistant-flow-staging'
+  IMPORT_MOVEMENTS_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:mcleod-import-movements-staging'
+  PARSED_CARRIER_SNS_TOPIC_ARN = 'arn:aws:sns:us-west-2:791608169866:mcleod-parsed-carrier-staging'
 
 class ProductionConfig(Config):
   """Configurations for running in dev mode, with a remote database."""
@@ -56,6 +62,7 @@ class ProductionConfig(Config):
 config_options = {
     'local': LocalConfig,
     'development': DevelopmentConfig,
+    'staging': StagingConfig,
     'production': ProductionConfig,
 }
 
